@@ -112,7 +112,7 @@ QString groupName(const QString &name)
         if (transliterator) {
             icu::UnicodeString icuText(reinterpret_cast<const char16_t *>(name.data()), name.size());
             transliterator->transliterate(icuText);
-            return QString::fromUtf16(icuText.getBuffer(), static_cast<int>(icuText.length())).left(1);
+            return QStringView(icuText.getBuffer(), static_cast<int>(icuText.length())).sliced(0, 1).toString();
         }
     }
 #endif
@@ -316,7 +316,6 @@ bool AppEntry::run(const QString &actionId, const QVariant &argument)
     if (actionId.isEmpty()) {
         auto *job = new KIO::ApplicationLauncherJob(m_service);
         job->setUiDelegate(new KNotificationJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled));
-        job->setRunFlags(KIO::ApplicationLauncherJob::DeleteTemporaryFiles);
         job->start();
 
         KActivities::ResourceInstance::notifyAccessed(QUrl(QStringLiteral("applications:") + m_service->storageId()), QStringLiteral("org.kde.plasma.kicker"));
