@@ -91,6 +91,10 @@ void PowerManagementJob::start()
         setResult(false);
         return;
     } else if (operation == QLatin1String("beginSuppressingSleep")) {
+        if (m_sleepInhibitionCookie != -1) { // an inhibition request is already active; don't trigger another one
+            setResult(true);
+            return;
+        }
         QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.PowerManagement.Inhibit"),
                                                           QStringLiteral("/org/freedesktop/PowerManagement/Inhibit"),
                                                           QStringLiteral("org.freedesktop.PowerManagement.Inhibit"),
@@ -99,6 +103,14 @@ void PowerManagementJob::start()
         QDBusReply<uint> reply = QDBusConnection::sessionBus().call(msg);
         m_sleepInhibitionCookie = reply.isValid() ? reply.value() : -1;
         setResult(reply.isValid());
+        if (reply.isValid() && !parameters().value(QStringLiteral("silent")).toBool()) {
+            QDBusMessage osdMsg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.plasmashell"),
+                                                                 QStringLiteral("/org/kde/osdService"),
+                                                                 QStringLiteral("org.kde.osdService"),
+                                                                 QStringLiteral("powerManagementInhibitedChanged"));
+            osdMsg << true;
+            QDBusConnection::sessionBus().asyncCall(osdMsg);
+        }
         return;
     } else if (operation == QLatin1String("stopSuppressingSleep")) {
         QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.PowerManagement.Inhibit"),
@@ -107,9 +119,22 @@ void PowerManagementJob::start()
                                                           QStringLiteral("UnInhibit"));
         msg << m_sleepInhibitionCookie;
         QDBusReply<void> reply = QDBusConnection::sessionBus().call(msg);
+        m_sleepInhibitionCookie = reply.isValid() ? -1 : m_sleepInhibitionCookie; // reset cookie if the stop request was successful
         setResult(reply.isValid());
+        if (reply.isValid() && !parameters().value(QStringLiteral("silent")).toBool()) {
+            QDBusMessage osdMsg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.plasmashell"),
+                                                                 QStringLiteral("/org/kde/osdService"),
+                                                                 QStringLiteral("org.kde.osdService"),
+                                                                 QStringLiteral("powerManagementInhibitedChanged"));
+            osdMsg << false;
+            QDBusConnection::sessionBus().asyncCall(osdMsg);
+        }
         return;
     } else if (operation == QLatin1String("beginSuppressingScreenPowerManagement")) {
+        if (m_lockInhibitionCookie != -1) { // an inhibition request is already active; don't trigger another one
+            setResult(true);
+            return;
+        }
         QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.ScreenSaver"),
                                                           QStringLiteral("/ScreenSaver"),
                                                           QStringLiteral("org.freedesktop.ScreenSaver"),
@@ -125,27 +150,10 @@ void PowerManagementJob::start()
                                                           QStringLiteral("org.freedesktop.ScreenSaver"),
                                                           QStringLiteral("UnInhibit"));
         msg << m_lockInhibitionCookie;
-        QDBusReply<void> reply = QDBusConnection::sessionBus().call(msg);
+        QDBusReply<uint> reply = QDBusConnection::sessionBus().call(msg);
+        m_lockInhibitionCookie = reply.isValid() ? -1 : m_lockInhibitionCookie; // reset cookie if the stop request was successful
         setResult(reply.isValid());
         return;
-    } else if (operation == QLatin1String("setBrightness")) {
-        auto pending = setScreenBrightness(parameters().value(QStringLiteral("brightness")).toInt(), parameters().value(QStringLiteral("silent")).toBool());
-        callWhenFinished(
-            pending,
-            [this](bool success) {
-                setResult(success);
-            },
-            this);
-        return;
-    } else if (operation == QLatin1String("setKeyboardBrightness")) {
-        auto pending = setKeyboardBrightness(parameters().value(QStringLiteral("brightness")).toInt(), parameters().value(QStringLiteral("silent")).toBool());
-        callWhenFinished(
-            pending,
-            [this](bool success) {
-                setResult(success);
-            },
-            this);
-        return;
     } else if (operation == QLatin1String("setPowerProfile")) {
         auto pending = setPowerProfile(parameters().value(QStringLiteral("profile")).toString());
         callWhenFinished(
@@ -155,32 +163,19 @@ void PowerManagementJob::start()
             },
             this);
         return;
+    } else if (operation == QLatin1String("showPowerProfileOsd")) {
+        QDBusMessage osdMsg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.plasmashell"),
+                                                             QStringLiteral("/org/kde/osdService"),
+                                                             QStringLiteral("org.kde.osdService"),
+                                                             QStringLiteral("powerProfileChanged"));
+        osdMsg << parameters().value(QStringLiteral("profile")).toString();
+        QDBusConnection::sessionBus().call(osdMsg);
     }
 
     qDebug() << "don't know what to do with " << operation;
     setResult(false);
 }
 
-QDBusPendingCall PowerManagementJob::setScreenBrightness(int value, bool silent)
-{
-    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Solid.PowerManagement"),
-                                                      QStringLiteral("/org/kde/Solid/PowerManagement/Actions/BrightnessControl"),
-                                                      QStringLiteral("org.kde.Solid.PowerManagement.Actions.BrightnessControl"),
-                                                      silent ? "setBrightnessSilent" : "setBrightness");
-    msg << value;
-    return QDBusConnection::sessionBus().asyncCall(msg);
-}
-
-QDBusPendingCall PowerManagementJob::setKeyboardBrightness(int value, bool silent)
-{
-    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Solid.PowerManagement"),
-                                                      QStringLiteral("/org/kde/Solid/PowerManagement/Actions/KeyboardBrightnessControl"),
-                                                      QStringLiteral("org.kde.Solid.PowerManagement.Actions.KeyboardBrightnessControl"),
-                                                      silent ? "setKeyboardBrightnessSilent" : "setKeyboardBrightness");
-    msg << value;
-    return QDBusConnection::sessionBus().asyncCall(msg);
-}
-
 QDBusPendingCall PowerManagementJob::setPowerProfile(const QString &value)
 {
     QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.Solid.PowerManagement"),
