@@ -10,27 +10,23 @@
 #include <KPluginMetaData>
 #include <KSycoca>
 
-#include <Plasma/DataContainer>
-#include <Plasma/PluginLoader>
+#include <Plasma5Support/DataContainer>
+#include <Plasma5Support/PluginLoader>
 
 #include "weatherenginedebug.h"
 
 // Constructor
-WeatherEngine::WeatherEngine(QObject *parent, const QVariantList &args)
-    : Plasma::DataEngine(parent, args)
+WeatherEngine::WeatherEngine(QObject *parent)
+    : Plasma5Support::DataEngine(parent)
 {
     m_reconnectTimer.setSingleShot(true);
     connect(&m_reconnectTimer, &QTimer::timeout, this, &WeatherEngine::startReconnect);
 
     // Globally notify all plugins to remove their sources (and unload plugin)
-    connect(this, &Plasma::DataEngine::sourceRemoved, this, &WeatherEngine::removeIonSource);
+    connect(this, &Plasma5Support::DataEngine::sourceRemoved, this, &WeatherEngine::removeIonSource);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    connect(&m_networkConfigurationManager, &QNetworkConfigurationManager::onlineStateChanged, this, &WeatherEngine::onOnlineStateChanged);
-#else
     QNetworkInformation::load(QNetworkInformation::Feature::Reachability);
     connect(QNetworkInformation::instance(), &QNetworkInformation::reachabilityChanged, this, &WeatherEngine::onOnlineStateChanged);
-#endif
 
     // Get the list of available plugins but don't load them
     connect(KSycoca::self(), &KSycoca::databaseChanged, this, &WeatherEngine::updateIonList);
@@ -48,9 +44,11 @@ WeatherEngine::~WeatherEngine()
 void WeatherEngine::updateIonList()
 {
     removeAllData(QStringLiteral("ions"));
-    const auto infos = Plasma::PluginLoader::self()->listDataEngineMetaData(QStringLiteral("weatherengine"));
+    const auto infos = Plasma5Support::PluginLoader::listDataEngineMetaData(QStringLiteral("weatherengine"));
     for (const KPluginMetaData &info : infos) {
-        const QString data = info.name() + QLatin1Char('|') + info.pluginId();
+        // We want to provide the short ion name, but pluginId is the full plugin library name
+        const QString ionName = info.pluginId().split(QLatin1Char('_')).last();
+        const QString data = QStringLiteral("%1|%2").arg(info.name()).arg(ionName);
         setData(QStringLiteral("ions"), info.pluginId(), data);
     }
 }
@@ -89,7 +87,7 @@ void WeatherEngine::removeIonSource(const QString &source)
 /**
  * SLOT: Push out new data to applet
  */
-void WeatherEngine::dataUpdated(const QString &source, const Plasma::DataEngine::Data &data)
+void WeatherEngine::dataUpdated(const QString &source, const Plasma5Support::DataEngine::Data &data)
 {
     qCDebug(WEATHER) << "dataUpdated() for:" << source;
     setData(source, data);
@@ -122,13 +120,8 @@ bool WeatherEngine::sourceRequestEvent(const QString &source)
     // is down. when it comes up again, then it will be refreshed
     ion->connectSource(source, this);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    qCDebug(WEATHER) << "sourceRequestEvent(): Network is: " << m_networkConfigurationManager.isOnline();
-    if (!m_networkConfigurationManager.isOnline()) {
-#else
     qCDebug(WEATHER) << "sourceRequestEvent(): Network is: " << QNetworkInformation::instance()->reachability();
     if (QNetworkInformation::instance()->reachability() != QNetworkInformation::Reachability::Online) {
-#endif
         setData(source, Data());
         return true;
     }
@@ -146,13 +139,8 @@ bool WeatherEngine::sourceRequestEvent(const QString &source)
  */
 bool WeatherEngine::updateSourceEvent(const QString &source)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    qCDebug(WEATHER) << "updateSourceEvent(): Network is: " << m_networkConfigurationManager.isOnline();
-    if (!m_networkConfigurationManager.isOnline()) {
-#else
     qCDebug(WEATHER) << "updateSourceEvent(): Network is: " << QNetworkInformation::instance()->reachability();
     if (QNetworkInformation::instance()->reachability() != QNetworkInformation::Reachability::Online) {
-#endif
         return false;
     }
 
@@ -165,15 +153,9 @@ bool WeatherEngine::updateSourceEvent(const QString &source)
     return ion->updateSourceEvent(source);
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void WeatherEngine::onOnlineStateChanged(bool isOnline)
-{
-    if (isOnline) {
-#else
 void WeatherEngine::onOnlineStateChanged(QNetworkInformation::Reachability reachability)
 {
     if (reachability == QNetworkInformation::Reachability::Online) {
-#endif
         qCDebug(WEATHER) << "starting m_reconnectTimer";
         // allow the network to settle down and actually come up
         m_reconnectTimer.start(1000);
@@ -200,7 +182,7 @@ void WeatherEngine::startReconnect()
 void WeatherEngine::forceUpdate(IonInterface *ion, const QString &source)
 {
     Q_UNUSED(ion);
-    Plasma::DataContainer *container = containerForSource(source);
+    Plasma5Support::DataContainer *container = containerForSource(source);
     if (container) {
         qCDebug(WEATHER) << "immediate update of" << source;
         container->forceImmediateUpdate();
@@ -222,7 +204,7 @@ IonInterface *WeatherEngine::ionForSource(const QString &source, QString *ionNam
     IonInterface *result = qobject_cast<IonInterface *>(dataEngine(name));
 
     if (result && ionName) {
-        *ionName = name;
+        *ionName = name.split(QLatin1Char('_')).last();
     }
 
     return result;
