@@ -34,6 +34,9 @@ class KCMRegionAndLang : public KQuickManagedConfigModule
 public:
     explicit KCMRegionAndLang(QObject *parent, const KPluginMetaData &data);
     void save() override;
+    void load() override;
+    void defaults() override;
+    bool isDefaults() const override;
 
     RegionAndLangSettings *settings() const;
 
@@ -45,11 +48,10 @@ public:
     Q_INVOKABLE void unset(KCM_RegionAndLang::SettingType setting) const;
     Q_INVOKABLE void reboot();
 
-public Q_SLOTS:
-    void load() override;
-
 Q_SIGNALS:
     void saveClicked();
+    void loadClicked();
+    void defaultsClicked();
     void takeEffectNextTime();
     void startGenerateLocale();
     void generateFinished();
@@ -74,4 +76,5 @@ private:
     LocaleGeneratorBase *m_generator = nullptr;
     QProcess *m_localectl = nullptr;
     bool m_enabled = false;
+    int m_loadedBinaryDialect;
 };
