@@ -12,11 +12,9 @@
 
 #include "klipper_debug.h"
 #include <KIO/PreviewJob>
-#include <QFutureWatcher>
 #include <QIcon>
-#include <QtConcurrent>
 
-#include <Prison/Prison>
+#include <Prison/Barcode>
 
 const static QString s_iconKey = QStringLiteral("icon");
 const static QString s_previewKey = QStringLiteral("preview");
@@ -25,7 +23,7 @@ const static QString s_previewHeightKey = QStringLiteral("previewHeight");
 const static QString s_urlKey = QStringLiteral("url");
 
 ClipboardJob::ClipboardJob(Klipper *klipper, const QString &destination, const QString &operation, const QVariantMap &parameters, QObject *parent)
-    : Plasma::ServiceJob(destination, operation, parameters, parent)
+    : Plasma5Support::ServiceJob(destination, operation, parameters, parent)
     , m_klipper(klipper)
 {
 }
@@ -46,7 +44,7 @@ void ClipboardJob::start()
 
     // other operations need the item
     HistoryItemConstPtr item = m_klipper->history()->find(QByteArray::fromBase64(destination().toUtf8()));
-    if (item.isNull()) {
+    if (!item) {
         setResult(false);
         return;
     }
@@ -59,9 +57,7 @@ void ClipboardJob::start()
     } else if (operation == QLatin1String("edit")) {
         if (parameters().contains(QLatin1String("text"))) {
             const QString text = parameters()[QLatin1String("text")].toString();
-            if (item) {
-                m_klipper->history()->remove(item);
-            }
+            m_klipper->history()->remove(item);
             m_klipper->history()->insert(HistoryItemPtr(new HistoryStringItem(text)));
             if (m_klipper->urlGrabber()) {
                 m_klipper->urlGrabber()->checkNewData(HistoryItemConstPtr(m_klipper->history()->first()));
@@ -69,42 +65,34 @@ void ClipboardJob::start()
             setResult(true);
             return;
         }
-        connect(m_klipper, &Klipper::editFinished, this, [this, item](HistoryItemConstPtr editedItem, int result) {
-            if (item != editedItem) {
-                // not our item
-                return;
-            }
-            setResult(result);
-        });
-        m_klipper->editData(item);
         return;
     } else if (operation == QLatin1String("barcode")) {
         int pixelWidth = parameters().value(QStringLiteral("width")).toInt();
         int pixelHeight = parameters().value(QStringLiteral("height")).toInt();
-        Prison::AbstractBarcode *code = nullptr;
+        std::optional<Prison::Barcode> code;
         switch (parameters().value(QStringLiteral("barcodeType")).toInt()) {
         case 1: {
-            code = Prison::createBarcode(Prison::DataMatrix);
+            code = Prison::Barcode::create(Prison::DataMatrix);
             const int size = qMin(pixelWidth, pixelHeight);
             pixelWidth = size;
             pixelHeight = size;
             break;
         }
         case 2: {
-            code = Prison::createBarcode(Prison::Code39);
+            code = Prison::Barcode::create(Prison::Code39);
             break;
         }
         case 3: {
-            code = Prison::createBarcode(Prison::Code93);
+            code = Prison::Barcode::create(Prison::Code93);
             break;
         }
         case 4: {
-            code = Prison::createBarcode(Prison::Aztec);
+            code = Prison::Barcode::create(Prison::Aztec);
             break;
         }
         case 0:
         default: {
-            code = Prison::createBarcode(Prison::QRCode);
+            code = Prison::Barcode::create(Prison::QRCode);
             const int size = qMin(pixelWidth, pixelHeight);
             pixelWidth = size;
             pixelHeight = size;
@@ -113,18 +101,7 @@ void ClipboardJob::start()
         }
         if (code) {
             code->setData(item->text());
-            QFutureWatcher<QImage> *watcher = new QFutureWatcher<QImage>(this);
-            connect(watcher, &QFutureWatcher<QImage>::finished, this, [this, watcher, code] {
-                setResult(watcher->result());
-                watcher->deleteLater();
-                delete code;
-            });
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            auto future = QtConcurrent::run(code, &Prison::AbstractBarcode::toImage, QSizeF(pixelWidth, pixelHeight));
-#else
-            auto future = QtConcurrent::run(&Prison::AbstractBarcode::toImage, code, QSizeF(pixelWidth, pixelHeight));
-#endif
-            watcher->setFuture(future);
+            setResult(code->toImage(QSizeF(pixelWidth, pixelHeight)));
             return;
         } else {
             setResult(false);
