@@ -13,8 +13,8 @@ class QMimeData;
 class QDataStream;
 
 class HistoryItem;
-typedef QSharedPointer<HistoryItem> HistoryItemPtr;
-typedef QSharedPointer<const HistoryItem> HistoryItemConstPtr;
+typedef std::shared_ptr<HistoryItem> HistoryItemPtr;
+typedef std::shared_ptr<const HistoryItem> HistoryItemConstPtr;
 
 enum class HistoryItemType {
     Text,
@@ -52,11 +52,14 @@ public:
     }
 
     /**
-     * Return the current item as pixmap
-     * A text would be returned as a null pixmap,
+     * Return the current item as \QImage
+     * A text would be returned as a null \QImage,
      * which is also the default implementation
      */
-    inline virtual QPixmap image() const;
+    virtual QImage image() const
+    {
+        return {};
+    }
 
     /**
      * Returns a pointer to a QMimeData suitable for QClipboard::setMimeData().
@@ -107,11 +110,6 @@ private:
     QByteArray m_uuid;
 };
 
-inline QPixmap HistoryItem::image() const
-{
-    return QPixmap();
-}
-
 inline QDataStream &operator<<(QDataStream &lhs, HistoryItem const *const rhs)
 {
     if (rhs) {
@@ -119,8 +117,3 @@ inline QDataStream &operator<<(QDataStream &lhs, HistoryItem const *const rhs)
     }
     return lhs;
 }
-
-Q_DECLARE_METATYPE(HistoryItem *)
-Q_DECLARE_METATYPE(HistoryItemPtr)
-Q_DECLARE_METATYPE(HistoryItemConstPtr)
-Q_DECLARE_METATYPE(HistoryItemType)
