@@ -55,7 +55,7 @@ QVariant HistoryModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
 
-    QSharedPointer<HistoryItem> item = m_items.at(index.row());
+    std::shared_ptr<HistoryItem> item = m_items.at(index.row());
 
     switch (role) {
     case Qt::DisplayRole:
@@ -63,7 +63,7 @@ QVariant HistoryModel::data(const QModelIndex &index, int role) const
     case Qt::DecorationRole:
         return item->image();
     case HistoryItemConstPtrRole:
-        return QVariant::fromValue<HistoryItemConstPtr>(qSharedPointerConstCast<const HistoryItem>(item));
+        return QVariant::fromValue<HistoryItemConstPtr>(std::const_pointer_cast<const HistoryItem>(item));
     case UuidRole:
         return item->uuid();
     case TypeRole:
@@ -120,9 +120,9 @@ QModelIndex HistoryModel::indexOf(const HistoryItem *item) const
     return indexOf(item->uuid());
 }
 
-void HistoryModel::insert(QSharedPointer<HistoryItem> item)
+void HistoryModel::insert(const std::shared_ptr<HistoryItem> &item)
 {
-    if (item.isNull()) {
+    if (!item) {
         return;
     }
 
@@ -152,7 +152,7 @@ void HistoryModel::insert(QSharedPointer<HistoryItem> item)
     }
 }
 
-void HistoryModel::clearAndBatchInsert(const QVector<HistoryItemPtr> &items)
+void HistoryModel::clearAndBatchInsert(const QList<HistoryItemPtr> &items)
 {
     if (m_maxSize == 0) {
         // special case - cannot insert any items
@@ -175,7 +175,7 @@ void HistoryModel::clearAndBatchInsert(const QVector<HistoryItemPtr> &items)
     m_items.reserve(numOfItemsToBeInserted);
 
     for (int i = 0; i < numOfItemsToBeInserted; i++) {
-        if (items[i].isNull()) {
+        if (!items[i]) {
             continue;
         }
 
