@@ -16,12 +16,13 @@ import time
 import unittest
 from typing import Final
 
-assert "appiumtests" in os.getcwd(), "Make sure the current directory is appiumtests"
-sys.path.append(os.getcwd())  # for appiumtests.utils
-
 from gi.repository import Gio, GLib
-from utils.GLibMainLoopThread import GLibMainLoopThread
-from utils.mediaplayer import (Mpris2, read_base_properties, read_player_metadata, read_player_properties)
+
+sys.path.append(os.path.join(os.path.dirname(os.path.abspath(__file__)), os.pardir, os.pardir, "appiumtests", "utils"))
+from GLibMainLoopThread import GLibMainLoopThread
+
+sys.path.append(os.path.join(os.path.dirname(os.path.abspath(__file__)), os.pardir, os.pardir, "appiumtests", "applets", "mediacontrollertest"))
+from mediaplayer import (Mpris2, read_base_properties, read_player_metadata, read_player_properties)
 
 KDE_VERSION: Final = 6
 SERVICE_NAME: Final = "org.freedesktop.DBus"
@@ -80,7 +81,7 @@ class MediaKeysTest(unittest.TestCase):
         kded_reply: GLib.Variant = session_bus.call_sync(f"org.kde.kded{KDE_VERSION}", "/kded", f"org.kde.kded{KDE_VERSION}", "loadModule", GLib.Variant("(s)", ["mprisservice"]), GLib.VariantType("(b)"), Gio.DBusSendMessageFlags.NONE, 1000)
         cls.assertTrue(kded_reply.get_child_value(0).get_boolean(), "mprisservice module is not loaded")
 
-        json_path: str = os.path.join(os.getcwd(), "resources/player_a.json")
+        json_path: str = os.path.join(os.path.dirname(os.path.abspath(__file__)), os.pardir, os.pardir, "appiumtests", "applets", "mediacontrollertest", "player_a.json")
         with open(json_path, "r", encoding="utf-8") as f:
             json_dict: dict[str, list | dict] = json.load(f)
         metadata: list[dict[str, GLib.Variant]] = read_player_metadata(json_dict)
