@@ -23,11 +23,11 @@ K_PLUGIN_CLASS_WITH_JSON(KillRunner, "plasma-runner-kill.json")
 
 KillRunner::KillRunner(QObject *parent, const KPluginMetaData &metaData)
     : KRunner::AbstractRunner(parent, metaData)
-    , m_processes(new KSysGuard::Processes(QString(), this))
     , m_actionList({
           KRunner::Action(QString::number(15), QStringLiteral("application-exit"), i18n("Send SIGTERM")),
           KRunner::Action(QString::number(9), QStringLiteral("process-stop"), i18n("Send SIGKILL")),
       })
+    , m_processes(new KSysGuard::Processes(QString(), this))
 {
     connect(this, &KRunner::AbstractRunner::prepare, m_processes, [this]() {
         m_needsRefresh = true;
@@ -92,10 +92,10 @@ void KillRunner::match(KRunner::RunnerContext &context)
         // Set the relevance
         switch (m_sorting) {
         case Sort::CPU:
-            match.setRelevance((process->userUsage() + process->sysUsage()) / 100);
+            match.setRelevance((process->userUsage() + process->sysUsage()) / 100.0);
             break;
         case Sort::CPUI:
-            match.setRelevance(1 - (process->userUsage() + process->sysUsage()) / 100);
+            match.setRelevance(1.0 - (process->userUsage() + process->sysUsage()) / 100.0);
             break;
         case Sort::NONE:
             match.setRelevance(name.compare(term, Qt::CaseInsensitive) == 0 ? 1 : 9);
