@@ -24,6 +24,23 @@
 
 using namespace MockCompositor;
 
+void copyDirectory(const QString &srcDir, const QString &dstDir)
+{
+    QDir targetDir(dstDir);
+    QVERIFY(targetDir.mkpath(dstDir));
+    QDirIterator it(srcDir, QDir::Filters(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot | QDir::Name), QDirIterator::Subdirectories);
+    while (it.hasNext()) {
+        it.next();
+        QString path = it.filePath();
+        QString relDestPath = path.last(it.filePath().length() - srcDir.length() - 1);
+        if (it.fileInfo().isDir()) {
+            QVERIFY(targetDir.mkpath(relDestPath));
+        } else {
+            QVERIFY(QFile::copy(path, dstDir % '/' % relDestPath));
+        }
+    }
+}
+
 class ShellTest : public QObject, DefaultCompositor
 {
     Q_OBJECT
@@ -46,9 +63,11 @@ private Q_SLOTS:
     void testReorderScreens_data();
     void testReorderScreens();
     void testReorderContainments();
+    void testPanelSizeModes();
 
 private:
     ShellCorona *m_corona;
+    QDir m_plasmaDir;
 };
 
 QScreen *ShellTest::insertScreen(const QRect &geometry, const QString &name)
@@ -133,6 +152,11 @@ void ShellTest::initTestCase()
     QStandardPaths::setTestModeEnabled(true);
     qRegisterMetaType<QScreen *>();
 
+    m_plasmaDir = QDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) % '/' % "plasma");
+    m_plasmaDir.removeRecursively();
+
+    copyDirectory(QFINDTESTDATA("data/testpanel"), m_plasmaDir.absolutePath() % "/plasmoids/org.kde.plasma.testpanel");
+
     KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("ScreenConnectors"));
     cg.deleteGroup();
     cg.sync();
@@ -168,6 +192,8 @@ void ShellTest::cleanupTestCase()
     cg.deleteGroup();
     cg.sync();
     delete m_corona;
+
+    // m_plasmaDir.removeRecursively();
 }
 
 void ShellTest::cleanup()
@@ -220,7 +246,8 @@ void ShellTest::testScreenInsertion()
 void ShellTest::testPanelInsertion()
 {
     QCOMPARE(m_corona->m_panelViews.size(), 0);
-    auto panelCont = m_corona->addPanel(QStringLiteral("org.kde.panel"));
+    auto panelCont = m_corona->addPanel(QStringLiteral("org.kde.plasma.testpanel"));
+    QCOMPARE(panelCont->pluginMetaData().pluginId(), QStringLiteral("org.kde.plasma.testpanel"));
     // If the panel fails to load (on ci plasma-desktop isn't here) we want the "failed" containment to be of panel type anyways
     QCOMPARE(m_corona->m_panelViews.size(), 1);
     QVERIFY(m_corona->m_panelViews.contains(panelCont));
@@ -614,6 +641,61 @@ void ShellTest::testReorderContainments()
     QCOMPARE(desktopViews[1]->screenToFollow(), screens[0]);
 }
 
+void ShellTest::testPanelSizeModes()
+{
+    // Testing variables
+    int thickness = 96;
+    int lengthMax = 300;
+    int lengthMin = lengthMax / 2;
+
+    // Create a panel and prepare it for testing
+    QCOMPARE(m_corona->m_panelViews.size(), 0);
+    auto panelCont = m_corona->addPanel(QStringLiteral("org.kde.plasma.testpanel"));
+    // If the panel fails to load (on ci plasma-desktop isn't here) we want the "failed" containment to be of panel type anyways
+    QCOMPARE(m_corona->m_panelViews.size(), 1);
+    QVERIFY(m_corona->m_panelViews.contains(panelCont));
+    QCOMPARE(panelCont->screen(), 0);
+    QCOMPARE(m_corona->m_panelViews[panelCont]->screen(), qApp->primaryScreen());
+
+    auto panel = m_corona->m_panelViews[panelCont];
+
+    // Plase panel to bottom edge of screen
+    panel->containment()->setLocation(Plasma::Types::BottomEdge);
+    QCOMPARE(panel->containment()->location(), Plasma::Types::BottomEdge);
+
+    // Set panel thickness
+    panel->setThickness(thickness);
+    QCOMPARE(panel->thickness(), thickness);
+
+    // Set panel lengths
+    panel->setLengthMode(PanelView::FillAvailable);
+    QCOMPARE(panel->size(), QSize(panel->screen()->size().width(), thickness)); // Panel should be screen width
+
+    panel->setLengthMode(PanelView::Custom);
+    panel->setMaximumLength(lengthMax);
+    panel->setMinimumLength(lengthMin);
+    QCOMPARE(panel->maximumLength(), lengthMax); // Panel should be custom width
+    QCOMPARE(panel->minimumLength(), lengthMin);
+    QCOMPARE(panel->size(), QSize(std::min(panel->length(), lengthMax), thickness)); // Panel should be screen width
+
+    panel->setLengthMode(PanelView::FitContent);
+    QCOMPARE(panel->size(), QSize(800, thickness));
+
+    // Test floating setting
+    panel->setFloating(true);
+    QVERIFY(panel->floating());
+    QCOMPARE(panel->thickness(), thickness);
+
+    panel->setFloating(false);
+    QVERIFY(!panel->floating());
+    QCOMPARE(panel->thickness(), thickness);
+
+    // Set vertical panel
+    panel->containment()->setLocation(Plasma::Types::LeftEdge);
+    panel->containment()->setFormFactor(Plasma::Types::Vertical);
+    QTRY_COMPARE(panel->size(), QSize(thickness, 800));
+}
+
 QCOMPOSITOR_TEST_MAIN(ShellTest)
 
 #include "shelltest.moc"
