@@ -154,6 +154,32 @@ void Osd::virtualKeyboardEnabledChanged(bool virtualKeyboardEnabled)
     }
 }
 
+void Osd::powerManagementInhibitedChanged(bool inhibited)
+{
+    if (inhibited) {
+        showText(QStringLiteral("system-suspend-inhibited"), i18nc("power management was inhibited, keep short", "Sleep and Screen Locking Blocked"));
+    } else {
+        showText(QStringLiteral("system-suspend-uninhibited"), i18nc("power management was uninhibited, keep short", "Sleep and Screen Locking Unblocked"));
+    }
+}
+
+void Osd::powerProfileChanged(const QString &profile)
+{
+    QString icon;
+    QString name;
+    if (profile == QStringLiteral("power-saver")) {
+        icon = QStringLiteral("battery-profile-powersave");
+        name = i18nc("Power profile was changed to power save mode, keep short", "Power Save Mode");
+    } else if (profile == QStringLiteral("balanced")) {
+        icon = QStringLiteral("speedometer");
+        name = i18nc("Power profile was changed to balanced mode, keep short", "Balanced Power Mode");
+    } else if (profile == QStringLiteral("performance")) {
+        icon = QStringLiteral("battery-profile-performance");
+        name = i18nc("Power profile was changed to performance mode, keep short", "Performance Mode");
+    }
+    showText(icon, name);
+}
+
 bool Osd::init()
 {
     if (!m_osdConfigGroup.readEntry("Enabled", true)) {
@@ -164,7 +190,7 @@ bool Osd::init()
         return true;
     }
 
-    const QUrl url = m_corona->lookAndFeelPackage().fileUrl("osdmainscript");
+    const QUrl url = m_corona->kPackage().fileUrl("osdmainscript");
     if (url.isEmpty()) {
         return false;
     }
@@ -177,7 +203,7 @@ bool Osd::init()
 
     if (m_osdObject->status() != QQmlComponent::Ready) {
         qCWarning(PLASMASHELL) << "Failed to load OSD QML file" << url;
-        auto fallbackUrl = m_corona->lookAndFeelPackage().fallbackPackage().fileUrl("osdmainscript");
+        auto fallbackUrl = m_corona->kPackage().fallbackPackage().fileUrl("osdmainscript");
         if (fallbackUrl.isEmpty() || fallbackUrl == url) {
             return false;
         }
